@@ -14,33 +14,33 @@ UnknownFieldEntry::UnknownFieldEntry(unsigned char t, size_t s,
 {
   uc_Type = t;
   st_length =s;
-  if (d != NULL) {
+  if (d != nullptr) {
     ASSERT(s != 0);
     uc_pUField = new unsigned char[s];
     memcpy(uc_pUField, d, s);
   } else
-    uc_pUField = NULL;
+    uc_pUField = nullptr;
 }
 
 UnknownFieldEntry::~UnknownFieldEntry()
 {
-  if (st_length > 0 && uc_pUField != NULL) {
+  if (st_length > 0 && uc_pUField != nullptr) {
     trashMemory(reinterpret_cast<void *>(uc_pUField), st_length);
     delete[] uc_pUField;
     st_length = 0;
-    uc_pUField = NULL;
+    uc_pUField = nullptr;
   }
 }
 
 UnknownFieldEntry::UnknownFieldEntry(const UnknownFieldEntry &that)
   : uc_Type(that.uc_Type), st_length(that.st_length)
 {
-  if (that.uc_pUField != NULL) {
+  if (that.uc_pUField != nullptr) {
     ASSERT(that.st_length != 0);
     uc_pUField = new unsigned char[st_length];
     memcpy(uc_pUField, that.uc_pUField, st_length);
   } else
-    uc_pUField = NULL;
+    uc_pUField = nullptr;
 }
 
 UnknownFieldEntry &UnknownFieldEntry::operator=(const UnknownFieldEntry &that)
@@ -48,7 +48,7 @@ UnknownFieldEntry &UnknownFieldEntry::operator=(const UnknownFieldEntry &that)
   if (this != &that) {
     uc_Type = that.uc_Type;
     st_length = that.st_length;
-    if (uc_pUField != NULL) {
+    if (uc_pUField != nullptr) {
       ASSERT(st_length != 0);
       trashMemory(uc_pUField, st_length);
     }
