@@ -164,10 +164,10 @@ void RestoreTreeItem(PWSTreeCtrl* tree, const string_or_uuid& val, TreeFunc func
 {
   wxTreeItemId id;
   switch(val.Type()) {
-    case string_or_uuid::ITEM_NORMAL:
+    case string_or_uuid::ItemType::NORMAL:
       id = tree->Find(static_cast<pws_os::CUUID> (val));
       break;
-    case string_or_uuid::ITEM_GROUP:
+    case string_or_uuid::ItemType::GROUP:
       id = tree->Find(static_cast<wxString>(val), tree->GetRootItem());
       break;
     default:
